@@ -1,6 +1,6 @@
 #!/usr/bin/env sh
 #
-# Simple hack script to restore __revision__, __COPYRIGHT_, 2.0.0.final.0
+# Simple hack script to restore __revision__, __COPYRIGHT_, 2.0.1
 # and other similar variables to what gets checked in to source.  This
 # comes in handy when people send in diffs based on the released source.
 #
@@ -24,7 +24,7 @@ for i in `find $DIRS -name '*.py'`; do
     ed $i <<EOF
 g/Copyright (c) 2001.*SCons Foundation/s//Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation/p
 w
-/^__revision__ = /s/= .*/= "bin/restore.sh 5023 2010/06/14 22:05:46 scons"/p
+/^__revision__ = /s/= .*/= "bin/restore.sh 5134 2010/08/16 23:02:40 bdeegan"/p
 w
 q
 EOF
@@ -35,7 +35,7 @@ for i in `find $DIRS -name 'scons.bat'`; do
     ed $i <<EOF
 g/Copyright (c) 2001.*SCons Foundation/s//Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation/p
 w
-/^@REM src\/script\/scons.bat/s/@REM .* knight/@REM bin/restore.sh 5023 2010/06/14 22:05:46 scons/p
+/^@REM src\/script\/scons.bat/s/@REM .* knight/@REM bin/restore.sh 5134 2010/08/16 23:02:40 bdeegan/p
 w
 q
 EOF
@@ -44,15 +44,15 @@ done
 for i in `find $DIRS -name '__init__.py' -o -name 'scons.py' -o -name 'sconsign.py'`; do
     header $i
     ed $i <<EOF
-/^__version__ = /s/= .*/= "2.0.0.final.0"/p
+/^__version__ = /s/= .*/= "2.0.1"/p
 w
-/^__build__ = /s/= .*/= "r5023"/p
+/^__build__ = /s/= .*/= "r5134"/p
 w
-/^__buildsys__ = /s/= .*/= "scons-dev"/p
+/^__buildsys__ = /s/= .*/= "cooldog"/p
 w
-/^__date__ = /s/= .*/= "2010/06/14 22:05:46"/p
+/^__date__ = /s/= .*/= "2010/08/16 23:02:40"/p
 w
-/^__developer__ = /s/= .*/= "scons"/p
+/^__developer__ = /s/= .*/= "bdeegan"/p
 w
 q
 EOF
@@ -61,7 +61,7 @@ done
 for i in `find $DIRS -name 'setup.py'`; do
     header $i
     ed $i <<EOF
-/^ *version = /s/= .*/= "2.0.0.final.0",/p
+/^ *version = /s/= .*/= "2.0.1",/p
 w
 q
 EOF
@@ -72,9 +72,9 @@ for i in `find $DIRS -name '*.txt'`; do
     ed $i <<EOF
 g/Copyright (c) 2001.*SCons Foundation/s//Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 The SCons Foundation/p
 w
-/# [^ ]* 0.96.[CD][0-9]* [0-9\/]* [0-9:]* knight$/s/.*/# bin/restore.sh 5023 2010/06/14 22:05:46 scons/p
+/# [^ ]* 0.96.[CD][0-9]* [0-9\/]* [0-9:]* knight$/s/.*/# bin/restore.sh 5134 2010/08/16 23:02:40 bdeegan/p
 w
-/Version [0-9][0-9]*\.[0-9][0-9]*/s//Version 2.0.0.final.0/p
+/Version [0-9][0-9]*\.[0-9][0-9]*/s//Version 2.0.1/p
 w
 q
 EOF
