@@ -57,7 +57,7 @@ In 'post' mode, files are prepared for the next release cycle:
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "bin/update-release-info.py 5023 2010/06/14 22:05:46 scons"
+__revision__ = "bin/update-release-info.py 5134 2010/08/16 23:02:40 bdeegan"
 
 import os
 import sys
@@ -114,7 +114,11 @@ if version_tuple[3] != 'final':
     else:
         yyyy,mm,dd,_,_,_ = release_date
         version_tuple = version_tuple[:4] + ((yyyy*100 + mm)*100 + dd,)
-version_string = '.'.join(map(str, version_tuple))
+    version_string = '.'.join(map(str, version_tuple))
+else:
+    # Final release doesn't have type or builddate in version string
+    version_string = '.'.join(map(str, version_tuple[:3]))
+
 version_type = version_tuple[3]
 if DEBUG: print 'version string', version_string
 
